@@ -5,8 +5,6 @@ import tensorflow as tf
 from tensorflow_tts.inference import TFAutoModel
 from tensorflow_tts.inference import AutoProcessor
 
-from EasyTTS.utils import Toolbox
-
 class TTS(object):
 
     """
@@ -14,7 +12,7 @@ class TTS(object):
     """ 
     def __new__(cls, lang="fr", text="Bonjour le monde"):
 
-        if lang not in Toolbox.SUPPORTED_LANGUAGES:
+        if lang not in ["fr","en"]:
             print("This language isn't supported yet!")
 
         if lang == "fr":
